#ifndef MSUPROJ_H
#define MSUPROJ_H
#include <msugcpgrid.h>
#include <gdal_priv.h>
namespace msumr {
class MSUPROJ_EXPORT MSUProj
{
public:
    MSUProj();
    MSUProj(const MSUProj &other);
    ~MSUProj();
    enum VERSION_TYPE
    {
        VERSION_STRING,
        VERSION_DATE,
        VERSION_ARCH
    };
    const char* version(VERSION_TYPE type = VERSION_STRING) const;
    void setDst(std::string file);
    void setDstFormat(std::string format);
    const RETURN_CODE setSrc(std::string file);
    const RETURN_CODE readGCP(std::string file);
    const RETURN_CODE warp(const bool &useUTM = false, const bool &zerosAsND = false);
    unsigned int srcXSize() const;
    unsigned int srcYSize() const;
    bool ifAddLogo() const;
    void setAddLogo(bool enabled);
    unsigned int *progressMaxPtr();
    unsigned int *progressValPtr();
    GCPGrid *gcpGrid() const;
private:
    enum BORDER_SIDE
    {
        BORDER_TOP,
        BORDER_BOTTOM,
        BORDER_RIGHT,
        BORDER_LEFT
    };
    RETURN_CODE calculateBorder(BORDER_SIDE side, const GCP *gcps,
                                const double *geoTransform,
                                double *border, const unsigned int &size) const;
private:
    bool mAddLogo;
    GDALDataset* mSrcDS;
    GCPGrid *mGcpGrid;
    std::string mDstFile;
    std::string mDstFormat;
    unsigned int mProgressMax;
    unsigned int mProgressVal;
};
}
#endif
